welcome to freqdemod's documentation!
=====================================

Contents:

.. toctree::
   :maxdepth: 1

   intro.rst
   quickstart.rst
   background.rst
   background1.rst
   background2.rst
   background3.rst
   demodulate.rst
   util.rst
   hdf5.rst
   tests.rst
   history.rst
   develop.rst
   license.rst
   acknow.rst


indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

